@@ -28,7 +28,7 @@ class TQComboBox;
 /** @short A link creator/remover. */
 class Links: public TQVBox
 {
-	Q_OBJECT
+	TQ_OBJECT
 public:
 	/**
 	 * Constructor.
