@@ -135,8 +135,8 @@ int KShutDownApplication::newInstance()
 		(void)new MMainWindow();
 		kapp->setMainWidget(ks_main);
 		connect(
-			this, SIGNAL(aboutToQuit()),
-			ks_main, SLOT(deleteLater()));
+			this, TQ_SIGNAL(aboutToQuit()),
+			ks_main, TQ_SLOT(deleteLater()));
 	}
 
 	// check command line args
