@@ -50,8 +50,8 @@ MStatsTab::MStatsTab()
 	_buf(TQString::null)
 {
 	_process = new TQProcess(this);
-	connect(_process, SIGNAL(processExited()), SLOT(slotProcessExit()));
-	connect(_process, SIGNAL(readyReadStdout()), SLOT(slotReadStdout()));
+	connect(_process, TQ_SIGNAL(processExited()), TQ_SLOT(slotProcessExit()));
+	connect(_process, TQ_SIGNAL(readyReadStdout()), TQ_SLOT(slotReadStdout()));
 
 	TQVBox *main = new TQVBox(this);
 	setMainWidget(main);
@@ -77,20 +77,20 @@ MStatsTab::MStatsTab()
 	TQHBox *buttons = new TQHBox(main);
 	// refresh
 	b_refresh = new KPushButton(SmallIcon("reload"), i18n("Refresh"), buttons, "KPushButton::b_refresh");
-	connect(b_refresh, SIGNAL(clicked()), SLOT(slotRefresh()));
+	connect(b_refresh, TQ_SIGNAL(clicked()), TQ_SLOT(slotRefresh()));
 
 	// options
 	TQVGroupBox *options = new TQVGroupBox(i18n("Options"), main);
 	// long format
 	c_longFormat = new TQCheckBox(i18n("More information"), options);
 	c_longFormat->setChecked(kshutdownrc->statsLongFormat);
-	connect(c_longFormat, SIGNAL(clicked()), SLOT(slotRefresh()));
+	connect(c_longFormat, TQ_SIGNAL(clicked()), TQ_SLOT(slotRefresh()));
 	MiscUtils::setHint(c_longFormat, i18n("Show login time, JCPU and PCPU times."));
 	// toggle from field
 	c_toggleFromField = new TQCheckBox(i18n("Toggle \"FROM\""), options);
 	c_toggleFromField->setChecked(kshutdownrc->statsToggleFromField);
 	MiscUtils::setHint(c_toggleFromField, i18n("Toggle the \"FROM\" (remote hostname) field."));
-	connect(c_toggleFromField, SIGNAL(clicked()), SLOT(slotRefresh()));
+	connect(c_toggleFromField, TQ_SIGNAL(clicked()), TQ_SLOT(slotRefresh()));
 
 	setButtonGuiItem(Details, KStdGuiItem::configure());
 	setDetailsWidget(options);
